==> cramr_ui_lib-0.0.12.tar.gz: test/routes/verb_indicative_test_route_test.dart <==
//TODO: introduce mocking
import 'package:cramr_ui_lib/model/study_mode.dart';
import 'package:cramr_ui_lib/model/study_mode_state.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_test_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';

void main() {
  testWidgets(
      'Testing for presence of fields and forward button. Some logic too.',
      (WidgetTester tester) async {
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(create: (BuildContext context) {
            var model = VerbTestModel();
            model.initialise(_randomIndicative, _randomPronouns, 'fr',
                'infinitive', 'translation');
            return model;
          }),
          ChangeNotifierProvider(create: (BuildContext context) {
            return StudyModeState(StudyMode.coverMode);
          })
        ],
        child: VerbIndicativeTestRoute(
          SettingsController(SettingsService(), ThemeMode.dark),
          key: UniqueKey(),
        )));

    Finder titleFinderOne = find.text('Vervoeging ');
    Finder titleFinderTwo = find.text(_randomInfinitive);
    expect(titleFinderOne, findsOneWidget);
    expect(titleFinderTwo, findsOneWidget);
    Finder forwardButtonFinder =
        find.byKey(const Key('evaluate_$_randomInfinitive'));
    expect(forwardButtonFinder, findsOneWidget);
    await tester.tap(forwardButtonFinder);
    await tester.pumpAndSettle();
    expect(titleFinderOne, findsOneWidget);
    int i = 0;
    _randomIndicative.forEach((element) async* {
      final Finder textFieldFinder =
          find.byKey(Key('test_${_randomInfinitive}_${i}'));
      expect(textFieldFinder, findsOneWidget);
      await tester.enterText(textFieldFinder, element);
      await tester.pumpAndSettle();
      i++;
    });
  });
}

==> cramr_ui_lib-0.0.14.tar.gz: test/routes/verb_indicative_test_route_test.dart <==
//TODO: introduce mocking
import 'package:cramr_ui_lib/model/cardinality_selection.dart';
import 'package:cramr_ui_lib/model/study_mode.dart';
import 'package:cramr_ui_lib/model/study_mode_state.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_test_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:cramr_ui_lib/util/cardinality_filter.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';

void main() {
  testWidgets('Testing for presence of all fields. Some logic too.',
      (WidgetTester tester) async {
    var selection = CardinalitySelection(true, true);
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(create: (BuildContext context) {
            var model = VerbTestModel();
            model.initialise(_randomIndicative, _randomPronouns, 'fr',
                'infinitive', 'translation');
            return model;
          }),
          ChangeNotifierProvider(create: (BuildContext context) {
            return StudyModeState(StudyMode.coverMode);
          })
        ],
        child: VerbIndicativeTestRoute(
          SettingsController(SettingsService(), ThemeMode.dark, selection),
          key: UniqueKey(),
        )));

    Finder titleFinderOne = find.text('Vervoeging ');
    Finder titleFinderTwo = find.text(_randomInfinitive);
    expect(titleFinderOne, findsOneWidget);
    expect(titleFinderTwo, findsOneWidget);
    Finder forwardButtonFinder =
        find.byKey(const Key('evaluate_$_randomInfinitive'));
    expect(forwardButtonFinder, findsOneWidget);
    await tester.tap(forwardButtonFinder);
    await tester.pumpAndSettle();
    expect(titleFinderOne, findsOneWidget);
    int i = 0;
    for (var element in _randomIndicative) {
      final Finder textFieldFinder =
          find.byKey(Key('test_${_randomInfinitive}_$i'));
      expect(textFieldFinder, findsOneWidget);
      await tester.enterText(textFieldFinder, element);
      await tester.pumpAndSettle();
      i++;
    }
  });

  testWidgets('Testing for presence of singular fields. Some logic too.',
      (WidgetTester tester) async {
    var selection = CardinalitySelection(true, false);
    var filteredPronounList =
        CardinalityFilter.filteredList(selection, _randomPronouns);
    var filteredIndicativeList =
        CardinalityFilter.filteredList(selection, _randomIndicative);
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(create: (BuildContext context) {
            var model = VerbTestModel();
            model.initialise(filteredIndicativeList, filteredPronounList, 'fr',
                'infinitive', 'translation');
            return model;
          }),
          ChangeNotifierProvider(create: (BuildContext context) {
            return StudyModeState(StudyMode.coverMode);
          })
        ],
        child: VerbIndicativeTestRoute(
          SettingsController(SettingsService(), ThemeMode.dark, selection),
          key: UniqueKey(),
        )));

    Finder titleFinderOne = find.text('Vervoeging ');
    Finder titleFinderTwo = find.text(_randomInfinitive);
    expect(titleFinderOne, findsOneWidget);
    expect(titleFinderTwo, findsOneWidget);
    Finder forwardButtonFinder =
        find.byKey(const Key('evaluate_$_randomInfinitive'));
    expect(forwardButtonFinder, findsOneWidget);
    await tester.tap(forwardButtonFinder);
    await tester.pumpAndSettle();
    expect(titleFinderOne, findsOneWidget);
    int i = 0;
    for (var element in filteredIndicativeList) {
      final Finder textFieldFinder =
          find.byKey(Key('test_${_randomInfinitive}_$i'));
      expect(textFieldFinder, findsOneWidget);
      await tester.enterText(textFieldFinder, element);
      await tester.pumpAndSettle();
      i++;
    }
  });

  testWidgets('Testing for presence of plural fields. Some logic too.',
      (WidgetTester tester) async {
    var selection = CardinalitySelection(false, true);
    var filteredPronounList =
        CardinalityFilter.filteredList(selection, _randomPronouns);
    var filteredIndicativeList =
        CardinalityFilter.filteredList(selection, _randomIndicative);
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(create: (BuildContext context) {
            var model = VerbTestModel();
            model.initialise(filteredIndicativeList, filteredPronounList, 'fr',
                'infinitive', 'translation');
            return model;
          }),
          ChangeNotifierProvider(create: (BuildContext context) {
            return StudyModeState(StudyMode.coverMode);
          })
        ],
        child: VerbIndicativeTestRoute(
          SettingsController(SettingsService(), ThemeMode.dark, selection),
          key: UniqueKey(),
        )));

    Finder titleFinderOne = find.text('Vervoeging ');
    Finder titleFinderTwo = find.text(_randomInfinitive);
    expect(titleFinderOne, findsOneWidget);
    expect(titleFinderTwo, findsOneWidget);
    Finder forwardButtonFinder =
        find.byKey(const Key('evaluate_$_randomInfinitive'));
    expect(forwardButtonFinder, findsOneWidget);
    await tester.tap(forwardButtonFinder);
    await tester.pumpAndSettle();
    expect(titleFinderOne, findsOneWidget);
    int i = 0;
    for (var element in filteredIndicativeList) {
      final Finder textFieldFinder =
          find.byKey(Key('test_${_randomInfinitive}_$i'));
      expect(textFieldFinder, findsOneWidget);
      await tester.enterText(textFieldFinder, element);
      await tester.pumpAndSettle();
      i++;
    }
  });
}
